@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union, cast
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -60,7 +72,7 @@ class AuthorizedCertificatesClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[AuthorizedCertificatesTransport]:
         """Returns an appropriate transport class.
 
@@ -261,7 +273,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -316,7 +328,7 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, AuthorizedCertificatesTransport, None] = None,
+        transport: Optional[Union[str, AuthorizedCertificatesTransport]] = None,
         client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -414,10 +426,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     def list_authorized_certificates(
         self,
-        request: Union[appengine.ListAuthorizedCertificatesRequest, dict] = None,
+        request: Optional[
+            Union[appengine.ListAuthorizedCertificatesRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAuthorizedCertificatesPager:
         r"""Lists all SSL certificates the user is authorized to
@@ -510,10 +524,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     def get_authorized_certificate(
         self,
-        request: Union[appengine.GetAuthorizedCertificateRequest, dict] = None,
+        request: Optional[
+            Union[appengine.GetAuthorizedCertificateRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> certificate.AuthorizedCertificate:
         r"""Gets the specified SSL certificate.
@@ -595,10 +611,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     def create_authorized_certificate(
         self,
-        request: Union[appengine.CreateAuthorizedCertificateRequest, dict] = None,
+        request: Optional[
+            Union[appengine.CreateAuthorizedCertificateRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> certificate.AuthorizedCertificate:
         r"""Uploads the specified SSL certificate.
@@ -680,10 +698,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     def update_authorized_certificate(
         self,
-        request: Union[appengine.UpdateAuthorizedCertificateRequest, dict] = None,
+        request: Optional[
+            Union[appengine.UpdateAuthorizedCertificateRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> certificate.AuthorizedCertificate:
         r"""Updates the specified SSL certificate. To renew a certificate
@@ -770,10 +790,12 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
 
     def delete_authorized_certificate(
         self,
-        request: Union[appengine.DeleteAuthorizedCertificateRequest, dict] = None,
+        request: Optional[
+            Union[appengine.DeleteAuthorizedCertificateRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified SSL certificate.
@@ -852,14 +874,9 @@ class AuthorizedCertificatesClient(metaclass=AuthorizedCertificatesClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AuthorizedCertificatesClient",)
