@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -126,7 +137,7 @@ class DomainMappingsAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -162,9 +173,9 @@ class DomainMappingsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DomainMappingsTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the domain mappings client.
@@ -208,10 +219,10 @@ class DomainMappingsAsyncClient:
 
     async def list_domain_mappings(
         self,
-        request: Union[appengine.ListDomainMappingsRequest, dict] = None,
+        request: Optional[Union[appengine.ListDomainMappingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDomainMappingsAsyncPager:
         r"""Lists the domain mappings on an application.
@@ -243,7 +254,7 @@ class DomainMappingsAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest, dict]]):
                 The request object. Request message for
                 `DomainMappings.ListDomainMappings`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -299,10 +310,10 @@ class DomainMappingsAsyncClient:
 
     async def get_domain_mapping(
         self,
-        request: Union[appengine.GetDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.GetDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> domain_mapping.DomainMapping:
         r"""Gets the specified domain mapping.
@@ -333,7 +344,7 @@ class DomainMappingsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.GetDomainMappingRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.GetDomainMappingRequest, dict]]):
                 The request object. Request message for
                 `DomainMappings.GetDomainMapping`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -378,10 +389,10 @@ class DomainMappingsAsyncClient:
 
     async def create_domain_mapping(
         self,
-        request: Union[appengine.CreateDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.CreateDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Maps a domain to an application. A user must be authorized to
@@ -413,13 +424,13 @@ class DomainMappingsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest, dict]]):
                 The request object. Request message for
                 `DomainMappings.CreateDomainMapping`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -475,10 +486,10 @@ class DomainMappingsAsyncClient:
 
     async def update_domain_mapping(
         self,
-        request: Union[appengine.UpdateDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.UpdateDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the specified domain mapping. To map an SSL certificate
@@ -511,13 +522,13 @@ class DomainMappingsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest, dict]]):
                 The request object. Request message for
                 `DomainMappings.UpdateDomainMapping`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -573,10 +584,10 @@ class DomainMappingsAsyncClient:
 
     async def delete_domain_mapping(
         self,
-        request: Union[appengine.DeleteDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.DeleteDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes the specified domain mapping. A user must be authorized
@@ -607,13 +618,13 @@ class DomainMappingsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest, dict]):
+            request (Optional[Union[google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest, dict]]):
                 The request object. Request message for
                 `DomainMappings.DeleteDomainMapping`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -681,14 +692,9 @@ class DomainMappingsAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DomainMappingsAsyncClient",)
