@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union, cast
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -63,7 +75,7 @@ class DomainMappingsClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[DomainMappingsTransport]:
         """Returns an appropriate transport class.
 
@@ -261,7 +273,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -316,7 +328,7 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, DomainMappingsTransport, None] = None,
+        transport: Optional[Union[str, DomainMappingsTransport]] = None,
         client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -414,10 +426,10 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     def list_domain_mappings(
         self,
-        request: Union[appengine.ListDomainMappingsRequest, dict] = None,
+        request: Optional[Union[appengine.ListDomainMappingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDomainMappingsPager:
         r"""Lists the domain mappings on an application.
@@ -506,10 +518,10 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     def get_domain_mapping(
         self,
-        request: Union[appengine.GetDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.GetDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> domain_mapping.DomainMapping:
         r"""Gets the specified domain mapping.
@@ -586,10 +598,10 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     def create_domain_mapping(
         self,
-        request: Union[appengine.CreateDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.CreateDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Maps a domain to an application. A user must be authorized to
@@ -684,10 +696,10 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     def update_domain_mapping(
         self,
-        request: Union[appengine.UpdateDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.UpdateDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Updates the specified domain mapping. To map an SSL certificate
@@ -783,10 +795,10 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
 
     def delete_domain_mapping(
         self,
-        request: Union[appengine.DeleteDomainMappingRequest, dict] = None,
+        request: Optional[Union[appengine.DeleteDomainMappingRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gac_operation.Operation:
         r"""Deletes the specified domain mapping. A user must be authorized
@@ -899,14 +911,9 @@ class DomainMappingsClient(metaclass=DomainMappingsClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DomainMappingsClient",)
