@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union, cast
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.appengine_admin_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -56,7 +68,7 @@ class FirewallClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[FirewallTransport]:
         """Returns an appropriate transport class.
 
@@ -265,7 +277,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -320,7 +332,7 @@ class FirewallClient(metaclass=FirewallClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, FirewallTransport, None] = None,
+        transport: Optional[Union[str, FirewallTransport]] = None,
         client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -418,10 +430,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     def list_ingress_rules(
         self,
-        request: Union[appengine.ListIngressRulesRequest, dict] = None,
+        request: Optional[Union[appengine.ListIngressRulesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListIngressRulesPager:
         r"""Lists the firewall rules of an application.
@@ -510,10 +522,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     def batch_update_ingress_rules(
         self,
-        request: Union[appengine.BatchUpdateIngressRulesRequest, dict] = None,
+        request: Optional[Union[appengine.BatchUpdateIngressRulesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> appengine.BatchUpdateIngressRulesResponse:
         r"""Replaces the entire firewall ruleset in one bulk operation. This
@@ -596,10 +608,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     def create_ingress_rule(
         self,
-        request: Union[appengine.CreateIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.CreateIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firewall.FirewallRule:
         r"""Creates a firewall rule for the application.
@@ -678,10 +690,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     def get_ingress_rule(
         self,
-        request: Union[appengine.GetIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.GetIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firewall.FirewallRule:
         r"""Gets the specified firewall rule.
@@ -760,10 +772,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     def update_ingress_rule(
         self,
-        request: Union[appengine.UpdateIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.UpdateIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> firewall.FirewallRule:
         r"""Updates the specified firewall rule.
@@ -842,10 +854,10 @@ class FirewallClient(metaclass=FirewallClientMeta):
 
     def delete_ingress_rule(
         self,
-        request: Union[appengine.DeleteIngressRuleRequest, dict] = None,
+        request: Optional[Union[appengine.DeleteIngressRuleRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified firewall rule.
@@ -922,14 +934,9 @@ class FirewallClient(metaclass=FirewallClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-appengine-admin",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("FirewallClient",)
