@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
@@ -109,7 +111,7 @@ class Version(proto.Message):
             sometimes referred to as "backends".
 
             This field is a member of `oneof`_ ``scaling``.
-        inbound_services (Sequence[google.cloud.appengine_admin_v1.types.InboundServiceType]):
+        inbound_services (MutableSequence[google.cloud.appengine_admin_v1.types.InboundServiceType]):
             Before an application can receive email or
             XMPP messages, the application must be
             configured to enable the service.
@@ -127,7 +129,7 @@ class Version(proto.Message):
             Extra network settings.
             Only applicable in the App Engine flexible
             environment.
-        zones (Sequence[str]):
+        zones (MutableSequence[str]):
             The Google Compute Engine zones that are
             supported by this version in the App Engine
             flexible environment. Deprecated.
@@ -149,7 +151,7 @@ class Version(proto.Message):
         app_engine_apis (bool):
             Allows App Engine second generation runtimes
             to access the legacy bundled services.
-        beta_settings (Mapping[str, str]):
+        beta_settings (MutableMapping[str, str]):
             Metadata settings that are supplied to this
             version to enable beta runtime features.
         env (str):
@@ -189,17 +191,17 @@ class Version(proto.Message):
             Appspot service account as default if this field
             is neither provided in app.yaml file nor through
             CLI flag.
-        handlers (Sequence[google.cloud.appengine_admin_v1.types.UrlMap]):
+        handlers (MutableSequence[google.cloud.appengine_admin_v1.types.UrlMap]):
             An ordered list of URL-matching patterns that should be
             applied to incoming requests. The first matching URL handles
             the request and other request handlers are not attempted.
 
             Only returned in ``GET`` requests if ``view=FULL`` is set.
-        error_handlers (Sequence[google.cloud.appengine_admin_v1.types.ErrorHandler]):
+        error_handlers (MutableSequence[google.cloud.appengine_admin_v1.types.ErrorHandler]):
             Custom static error pages. Limited to 10KB per page.
 
             Only returned in ``GET`` requests if ``view=FULL`` is set.
-        libraries (Sequence[google.cloud.appengine_admin_v1.types.Library]):
+        libraries (MutableSequence[google.cloud.appengine_admin_v1.types.Library]):
             Configuration for third-party Python runtime libraries that
             are required by the application.
 
@@ -209,11 +211,11 @@ class Version(proto.Message):
             Endpoints <https://cloud.google.com/appengine/docs/python/endpoints/>`__.
 
             Only returned in ``GET`` requests if ``view=FULL`` is set.
-        env_variables (Mapping[str, str]):
+        env_variables (MutableMapping[str, str]):
             Environment variables available to the application.
 
             Only returned in ``GET`` requests if ``view=FULL`` is set.
-        build_env_variables (Mapping[str, str]):
+        build_env_variables (MutableMapping[str, str]):
             Environment variables available to the build environment.
 
             Only returned in ``GET`` requests if ``view=FULL`` is set.
@@ -266,188 +268,188 @@ class Version(proto.Message):
             Enables VPC connectivity for standard apps.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    id = proto.Field(
+    id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    automatic_scaling = proto.Field(
+    automatic_scaling: "AutomaticScaling" = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="scaling",
         message="AutomaticScaling",
     )
-    basic_scaling = proto.Field(
+    basic_scaling: "BasicScaling" = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="scaling",
         message="BasicScaling",
     )
-    manual_scaling = proto.Field(
+    manual_scaling: "ManualScaling" = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="scaling",
         message="ManualScaling",
     )
-    inbound_services = proto.RepeatedField(
+    inbound_services: MutableSequence["InboundServiceType"] = proto.RepeatedField(
         proto.ENUM,
         number=6,
         enum="InboundServiceType",
     )
-    instance_class = proto.Field(
+    instance_class: str = proto.Field(
         proto.STRING,
         number=7,
     )
-    network = proto.Field(
+    network: "Network" = proto.Field(
         proto.MESSAGE,
         number=8,
         message="Network",
     )
-    zones = proto.RepeatedField(
+    zones: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=118,
     )
-    resources = proto.Field(
+    resources: "Resources" = proto.Field(
         proto.MESSAGE,
         number=9,
         message="Resources",
     )
-    runtime = proto.Field(
+    runtime: str = proto.Field(
         proto.STRING,
         number=10,
     )
-    runtime_channel = proto.Field(
+    runtime_channel: str = proto.Field(
         proto.STRING,
         number=117,
     )
-    threadsafe = proto.Field(
+    threadsafe: bool = proto.Field(
         proto.BOOL,
         number=11,
     )
-    vm = proto.Field(
+    vm: bool = proto.Field(
         proto.BOOL,
         number=12,
     )
-    app_engine_apis = proto.Field(
+    app_engine_apis: bool = proto.Field(
         proto.BOOL,
         number=128,
     )
-    beta_settings = proto.MapField(
+    beta_settings: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=13,
     )
-    env = proto.Field(
+    env: str = proto.Field(
         proto.STRING,
         number=14,
     )
-    serving_status = proto.Field(
+    serving_status: "ServingStatus" = proto.Field(
         proto.ENUM,
         number=15,
         enum="ServingStatus",
     )
-    created_by = proto.Field(
+    created_by: str = proto.Field(
         proto.STRING,
         number=16,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=17,
         message=timestamp_pb2.Timestamp,
     )
-    disk_usage_bytes = proto.Field(
+    disk_usage_bytes: int = proto.Field(
         proto.INT64,
         number=18,
     )
-    runtime_api_version = proto.Field(
+    runtime_api_version: str = proto.Field(
         proto.STRING,
         number=21,
     )
-    runtime_main_executable_path = proto.Field(
+    runtime_main_executable_path: str = proto.Field(
         proto.STRING,
         number=22,
     )
-    service_account = proto.Field(
+    service_account: str = proto.Field(
         proto.STRING,
         number=127,
     )
-    handlers = proto.RepeatedField(
+    handlers: MutableSequence[app_yaml.UrlMap] = proto.RepeatedField(
         proto.MESSAGE,
         number=100,
         message=app_yaml.UrlMap,
     )
-    error_handlers = proto.RepeatedField(
+    error_handlers: MutableSequence[app_yaml.ErrorHandler] = proto.RepeatedField(
         proto.MESSAGE,
         number=101,
         message=app_yaml.ErrorHandler,
     )
-    libraries = proto.RepeatedField(
+    libraries: MutableSequence[app_yaml.Library] = proto.RepeatedField(
         proto.MESSAGE,
         number=102,
         message=app_yaml.Library,
     )
-    api_config = proto.Field(
+    api_config: app_yaml.ApiConfigHandler = proto.Field(
         proto.MESSAGE,
         number=103,
         message=app_yaml.ApiConfigHandler,
     )
-    env_variables = proto.MapField(
+    env_variables: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=104,
     )
-    build_env_variables = proto.MapField(
+    build_env_variables: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=125,
     )
-    default_expiration = proto.Field(
+    default_expiration: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=105,
         message=duration_pb2.Duration,
     )
-    health_check = proto.Field(
+    health_check: app_yaml.HealthCheck = proto.Field(
         proto.MESSAGE,
         number=106,
         message=app_yaml.HealthCheck,
     )
-    readiness_check = proto.Field(
+    readiness_check: app_yaml.ReadinessCheck = proto.Field(
         proto.MESSAGE,
         number=112,
         message=app_yaml.ReadinessCheck,
     )
-    liveness_check = proto.Field(
+    liveness_check: app_yaml.LivenessCheck = proto.Field(
         proto.MESSAGE,
         number=113,
         message=app_yaml.LivenessCheck,
     )
-    nobuild_files_regex = proto.Field(
+    nobuild_files_regex: str = proto.Field(
         proto.STRING,
         number=107,
     )
-    deployment = proto.Field(
+    deployment: deploy.Deployment = proto.Field(
         proto.MESSAGE,
         number=108,
         message=deploy.Deployment,
     )
-    version_url = proto.Field(
+    version_url: str = proto.Field(
         proto.STRING,
         number=109,
     )
-    endpoints_api_service = proto.Field(
+    endpoints_api_service: "EndpointsApiService" = proto.Field(
         proto.MESSAGE,
         number=110,
         message="EndpointsApiService",
     )
-    entrypoint = proto.Field(
+    entrypoint: "Entrypoint" = proto.Field(
         proto.MESSAGE,
         number=122,
         message="Entrypoint",
     )
-    vpc_access_connector = proto.Field(
+    vpc_access_connector: "VpcAccessConnector" = proto.Field(
         proto.MESSAGE,
         number=121,
         message="VpcAccessConnector",
@@ -500,20 +502,20 @@ class EndpointsApiService(proto.Message):
         FIXED = 1
         MANAGED = 2
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    config_id = proto.Field(
+    config_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    rollout_strategy = proto.Field(
+    rollout_strategy: RolloutStrategy = proto.Field(
         proto.ENUM,
         number=3,
         enum=RolloutStrategy,
     )
-    disable_trace_sampling = proto.Field(
+    disable_trace_sampling: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
@@ -570,62 +572,62 @@ class AutomaticScaling(proto.Message):
             Scheduler settings for standard environment.
     """
 
-    cool_down_period = proto.Field(
+    cool_down_period: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=1,
         message=duration_pb2.Duration,
     )
-    cpu_utilization = proto.Field(
+    cpu_utilization: "CpuUtilization" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="CpuUtilization",
     )
-    max_concurrent_requests = proto.Field(
+    max_concurrent_requests: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    max_idle_instances = proto.Field(
+    max_idle_instances: int = proto.Field(
         proto.INT32,
         number=4,
     )
-    max_total_instances = proto.Field(
+    max_total_instances: int = proto.Field(
         proto.INT32,
         number=5,
     )
-    max_pending_latency = proto.Field(
+    max_pending_latency: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=6,
         message=duration_pb2.Duration,
     )
-    min_idle_instances = proto.Field(
+    min_idle_instances: int = proto.Field(
         proto.INT32,
         number=7,
     )
-    min_total_instances = proto.Field(
+    min_total_instances: int = proto.Field(
         proto.INT32,
         number=8,
     )
-    min_pending_latency = proto.Field(
+    min_pending_latency: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=9,
         message=duration_pb2.Duration,
     )
-    request_utilization = proto.Field(
+    request_utilization: "RequestUtilization" = proto.Field(
         proto.MESSAGE,
         number=10,
         message="RequestUtilization",
     )
-    disk_utilization = proto.Field(
+    disk_utilization: "DiskUtilization" = proto.Field(
         proto.MESSAGE,
         number=11,
         message="DiskUtilization",
     )
-    network_utilization = proto.Field(
+    network_utilization: "NetworkUtilization" = proto.Field(
         proto.MESSAGE,
         number=12,
         message="NetworkUtilization",
     )
-    standard_scheduler_settings = proto.Field(
+    standard_scheduler_settings: "StandardSchedulerSettings" = proto.Field(
         proto.MESSAGE,
         number=20,
         message="StandardSchedulerSettings",
@@ -648,12 +650,12 @@ class BasicScaling(proto.Message):
             this version.
     """
 
-    idle_timeout = proto.Field(
+    idle_timeout: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=1,
         message=duration_pb2.Duration,
     )
-    max_instances = proto.Field(
+    max_instances: int = proto.Field(
         proto.INT32,
         number=2,
     )
@@ -672,7 +674,7 @@ class ManualScaling(proto.Message):
             ``set_num_instances()`` function.
     """
 
-    instances = proto.Field(
+    instances: int = proto.Field(
         proto.INT32,
         number=1,
     )
@@ -690,12 +692,12 @@ class CpuUtilization(proto.Message):
             scaling. Must be between 0 and 1.
     """
 
-    aggregation_window_length = proto.Field(
+    aggregation_window_length: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=1,
         message=duration_pb2.Duration,
     )
-    target_utilization = proto.Field(
+    target_utilization: float = proto.Field(
         proto.DOUBLE,
         number=2,
     )
@@ -712,11 +714,11 @@ class RequestUtilization(proto.Message):
             Target number of concurrent requests.
     """
 
-    target_request_count_per_second = proto.Field(
+    target_request_count_per_second: int = proto.Field(
         proto.INT32,
         number=1,
     )
-    target_concurrent_requests = proto.Field(
+    target_concurrent_requests: int = proto.Field(
         proto.INT32,
         number=2,
     )
@@ -737,19 +739,19 @@ class DiskUtilization(proto.Message):
             Target ops read per seconds.
     """
 
-    target_write_bytes_per_second = proto.Field(
+    target_write_bytes_per_second: int = proto.Field(
         proto.INT32,
         number=14,
     )
-    target_write_ops_per_second = proto.Field(
+    target_write_ops_per_second: int = proto.Field(
         proto.INT32,
         number=15,
     )
-    target_read_bytes_per_second = proto.Field(
+    target_read_bytes_per_second: int = proto.Field(
         proto.INT32,
         number=16,
     )
-    target_read_ops_per_second = proto.Field(
+    target_read_ops_per_second: int = proto.Field(
         proto.INT32,
         number=17,
     )
@@ -770,19 +772,19 @@ class NetworkUtilization(proto.Message):
             Target packets received per second.
     """
 
-    target_sent_bytes_per_second = proto.Field(
+    target_sent_bytes_per_second: int = proto.Field(
         proto.INT32,
         number=1,
     )
-    target_sent_packets_per_second = proto.Field(
+    target_sent_packets_per_second: int = proto.Field(
         proto.INT32,
         number=11,
     )
-    target_received_bytes_per_second = proto.Field(
+    target_received_bytes_per_second: int = proto.Field(
         proto.INT32,
         number=12,
     )
-    target_received_packets_per_second = proto.Field(
+    target_received_packets_per_second: int = proto.Field(
         proto.INT32,
         number=13,
     )
@@ -806,19 +808,19 @@ class StandardSchedulerSettings(proto.Message):
             zero to disable ``max_instances`` configuration.
     """
 
-    target_cpu_utilization = proto.Field(
+    target_cpu_utilization: float = proto.Field(
         proto.DOUBLE,
         number=1,
     )
-    target_throughput_utilization = proto.Field(
+    target_throughput_utilization: float = proto.Field(
         proto.DOUBLE,
         number=2,
     )
-    min_instances = proto.Field(
+    min_instances: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    max_instances = proto.Field(
+    max_instances: int = proto.Field(
         proto.INT32,
         number=4,
     )
@@ -829,7 +831,7 @@ class Network(proto.Message):
     Only applicable in the App Engine flexible environment.
 
     Attributes:
-        forwarded_ports (Sequence[str]):
+        forwarded_ports (MutableSequence[str]):
             List of ports, or port pairs, to forward from
             the virtual machine to the application
             container. Only applicable in the App Engine
@@ -871,23 +873,23 @@ class Network(proto.Message):
             environment.
     """
 
-    forwarded_ports = proto.RepeatedField(
+    forwarded_ports: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
-    instance_tag = proto.Field(
+    instance_tag: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    subnetwork_name = proto.Field(
+    subnetwork_name: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    session_affinity = proto.Field(
+    session_affinity: bool = proto.Field(
         proto.BOOL,
         number=5,
     )
@@ -906,15 +908,15 @@ class Volume(proto.Message):
             Volume size in gigabytes.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    volume_type = proto.Field(
+    volume_type: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    size_gb = proto.Field(
+    size_gb: float = proto.Field(
         proto.DOUBLE,
         number=3,
     )
@@ -930,7 +932,7 @@ class Resources(proto.Message):
             Disk size (GB) needed.
         memory_gb (float):
             Memory (GB) needed.
-        volumes (Sequence[google.cloud.appengine_admin_v1.types.Volume]):
+        volumes (MutableSequence[google.cloud.appengine_admin_v1.types.Volume]):
             User specified volumes.
         kms_key_reference (str):
             The name of the encryption key that is stored
@@ -938,24 +940,24 @@ class Resources(proto.Message):
             Cloud Composer to encrypt the vm disk
     """
 
-    cpu = proto.Field(
+    cpu: float = proto.Field(
         proto.DOUBLE,
         number=1,
     )
-    disk_gb = proto.Field(
+    disk_gb: float = proto.Field(
         proto.DOUBLE,
         number=2,
     )
-    memory_gb = proto.Field(
+    memory_gb: float = proto.Field(
         proto.DOUBLE,
         number=3,
     )
-    volumes = proto.RepeatedField(
+    volumes: MutableSequence["Volume"] = proto.RepeatedField(
         proto.MESSAGE,
         number=4,
         message="Volume",
     )
-    kms_key_reference = proto.Field(
+    kms_key_reference: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -984,11 +986,11 @@ class VpcAccessConnector(proto.Message):
         ALL_TRAFFIC = 1
         PRIVATE_IP_RANGES = 2
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    egress_setting = proto.Field(
+    egress_setting: EgressSetting = proto.Field(
         proto.ENUM,
         number=2,
         enum=EgressSetting,
@@ -1008,7 +1010,7 @@ class Entrypoint(proto.Message):
             This field is a member of `oneof`_ ``command``.
     """
 
-    shell = proto.Field(
+    shell: str = proto.Field(
         proto.STRING,
         number=1,
         oneof="command",
